@@ -29,11 +29,30 @@
 #define DEBUG_KP_DOCUMENT 0
 
 
-#include <kpDocument.h>
-#include <kpDocumentPrivate.h>
+#include "kpDocument.h"
+#include "kpDocumentPrivate.h"
+
+#include "layers/selections/kpAbstractSelection.h"
+#include "layers/selections/image/kpAbstractImageSelection.h"
+#include "imagelib/kpColor.h"
+#include "widgets/toolbars/kpColorToolBar.h"
+#include "kpDefs.h"
+#include "environments/document/kpDocumentEnvironment.h"
+#include "document/kpDocumentSaveOptions.h"
+#include "imagelib/kpDocumentMetaInfo.h"
+#include "imagelib/effects/kpEffectReduceColors.h"
+#include "pixmapfx/kpPixmapFX.h"
+#include "tools/kpTool.h"
+#include "widgets/toolbars/kpToolToolBar.h"
+#include "lgpl/generic/kpUrlFormatter.h"
 
 #include <math.h>
 
+#include <kdebug.h>
+#include <kimageio.h>
+#include <kio/netaccess.h>
+#include <klocale.h>
+
 #include <qcolor.h>
 #include <qbitmap.h>
 #include <qbrush.h>
@@ -46,27 +65,6 @@
 #include <qsize.h>
 #include <qmatrix.h>
 
-#include <kdebug.h>
-#include <kglobal.h>
-#include <kimageio.h>
-#include <kio/netaccess.h>
-#include <klocale.h>
-#include <ktemporaryfile.h>
-
-#include <kpAbstractSelection.h>
-#include <kpAbstractImageSelection.h>
-#include <kpColor.h>
-#include <kpColorToolBar.h>
-#include <kpDefs.h>
-#include <kpDocumentEnvironment.h>
-#include <kpDocumentSaveOptions.h>
-#include <kpDocumentMetaInfo.h>
-#include <kpEffectReduceColors.h>
-#include <kpPixmapFX.h>
-#include <kpTool.h>
-#include <kpToolToolBar.h>
-#include <kpUrlFormatter.h>
-
 //---------------------------------------------------------------------
 
 kpDocument::kpDocument (int w, int h,
@@ -133,7 +131,7 @@ bool kpDocument::savedAtLeastOnceBefore () const
 //---------------------------------------------------------------------
 
 // public
-KUrl kpDocument::url () const
+QUrl kpDocument::url () const
 {
     return m_url;
 }
@@ -141,7 +139,7 @@ KUrl kpDocument::url () const
 //---------------------------------------------------------------------
 
 // public
-void kpDocument::setURL (const KUrl &url, bool isFromURL)
+void kpDocument::setURL (const QUrl &url, bool isFromURL)
 {
     m_url = url;
     m_isFromURL = isFromURL;
@@ -464,5 +462,4 @@ void kpDocument::slotSizeChanged (const QSize &newSize)
 //---------------------------------------------------------------------
 
 
-#include <kpDocument.moc>
 
